0.5.0 (2017-01-11)
------------------

- First version of docker-registry-client with changelog
- Support get and push manifest on protocol v2, schema v1.
  (`Issue #33 <https://github.com/yodle/docker-registry-client/pull/33>`_)
